@@ -14,18 +14,22 @@ from .requests import delete, get, post, post_json, put, put_json
 from .response_classifier import DefaultResponseClassifier, ResponseClassifier, ResponseVerdict
 from .strategy import (
     MethodBasedStrategy,
+    ParallelRequestStrategy,
     RequestStrategy,
     SendRequestFunc,
     SendRequestResult,
+    SequentialRequestStrategy,
+    SingleAttemptRequestStrategy,
     parallel_strategy,
     sequential_strategy,
+    single_attempt_strategy,
 )
 from .transport import Transport
 
 try:
     import aiohttp
 
-    from .aiohttp import AioHttpTransport, aiohttp_middleware_factory
+    from .aiohttp import AioHttpTransport, aiohttp_middleware_factory, aiohttp_timeout
 except ImportError:
     pass
 
@@ -36,7 +40,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "0.1.2"
+__version__ = "0.1.4"
 
 version = f"{__version__}, Python {sys.version}"
 
