@@ -1,4 +1,6 @@
-from typing import AsyncContextManager, Callable, Optional, Union
+import contextlib
+from collections.abc import Callable
+from typing import Optional, Union
 
 import yarl
 
@@ -8,7 +10,13 @@ from .deadline import Deadline
 from .delays_provider import linear_delays
 from .priority import Priority
 from .response_classifier import DefaultResponseClassifier, ResponseClassifier
-from .strategy import MethodBasedStrategy, RequestStrategy, SendRequestResult, sequential_strategy
+from .strategy import (
+    MethodBasedStrategy,
+    RequestStrategy,
+    SendRequestResult,
+    sequential_strategy,
+    single_attempt_strategy,
+)
 from .transport import Transport
 
 
@@ -55,7 +63,7 @@ class Client:
         deadline: Optional[Deadline] = None,
         priority: Optional[Priority] = None,
         strategy: Optional[RequestStrategy] = None,
-    ) -> AsyncContextManager[Response]:
+    ) -> contextlib.AbstractAsyncContextManager[Response]:
         if self._request_enricher is not None:
             request = self._request_enricher(request)
         context = get_context()
@@ -86,8 +94,9 @@ class Client:
         if self._emit_system_headers:
             request = request.update_headers(
                 {
-                    Header.X_REQUEST_DEADLINE_AT: str(deadline),
+                    Header.X_REQUEST_DEADLINE_AT: str(deadline),  # for backward compatibility
                     Header.X_REQUEST_PRIORITY: str(priority),
+                    Header.X_REQUEST_TIMEOUT: str(deadline.timeout),
                 }
             )
 
@@ -104,7 +113,7 @@ def setup(
     transport: Transport,
     endpoint: Union[str, yarl.URL],
     safe_method_strategy: RequestStrategy = sequential_strategy(attempts_count=3, delays_provider=linear_delays()),
-    unsafe_method_strategy: RequestStrategy = sequential_strategy(attempts_count=1, delays_provider=linear_delays()),
+    unsafe_method_strategy: RequestStrategy = single_attempt_strategy(),
     response_classifier: Optional[ResponseClassifier] = None,
     timeout: float = 20.0,
     priority: Priority = Priority.NORMAL,
