@@ -1,7 +1,8 @@
 import abc
 import asyncio
 import contextlib
-from typing import AsyncContextManager, AsyncIterator, Awaitable, Callable, Dict, List, Set
+from collections.abc import AsyncIterator, Awaitable, Callable
+from typing import Optional
 
 import yarl
 
@@ -10,7 +11,7 @@ from .deadline import Deadline
 from .delays_provider import linear_delays
 from .priority import Priority
 from .response_classifier import ResponseVerdict
-from .utils import cancel_futures, close, close_futures
+from .utils import cancel_futures, close, close_futures, close_single
 
 
 class SendRequestResult:
@@ -35,14 +36,14 @@ class RequestStrategy(abc.ABC):
         request: Request,
         deadline: Deadline,
         priority: Priority,
-    ) -> AsyncContextManager[Response]:
+    ) -> contextlib.AbstractAsyncContextManager[Response]:
         ...
 
 
 class MethodBasedStrategy(RequestStrategy):
     __slots__ = ("_strategy_by_method",)
 
-    def __init__(self, strategy_by_method: Dict[str, RequestStrategy]):
+    def __init__(self, strategy_by_method: dict[str, RequestStrategy]):
         self._strategy_by_method = strategy_by_method
 
     def request(
@@ -52,10 +53,14 @@ class MethodBasedStrategy(RequestStrategy):
         request: Request,
         deadline: Deadline,
         priority: Priority,
-    ) -> AsyncContextManager[Response]:
+    ) -> contextlib.AbstractAsyncContextManager[Response]:
         return self._strategy_by_method[request.method].request(send_request, endpoint, request, deadline, priority)
 
 
+def single_attempt_strategy() -> RequestStrategy:
+    return SingleAttemptRequestStrategy()
+
+
 def sequential_strategy(
     *, attempts_count: int = 3, delays_provider: Callable[[int], float] = linear_delays()
 ) -> RequestStrategy:
@@ -74,6 +79,27 @@ def parallel_strategy(
     )
 
 
+class SingleAttemptRequestStrategy(RequestStrategy):
+    __slots__ = ()
+
+    @contextlib.asynccontextmanager
+    async def request(
+        self,
+        send_request: SendRequestFunc,
+        endpoint: yarl.URL,
+        request: Request,
+        deadline: Deadline,
+        priority: Priority,
+    ) -> AsyncIterator[Response]:
+        send_result: Optional[SendRequestResult] = None
+        try:
+            send_result = await send_request(endpoint, request, deadline, priority)
+            yield send_result.response
+        finally:
+            if send_result is not None:
+                await asyncio.shield(close_single(send_result.response))
+
+
 class SequentialRequestStrategy(RequestStrategy):
     __slots__ = (
         "_attempts_count",
@@ -101,7 +127,7 @@ class SequentialRequestStrategy(RequestStrategy):
         deadline: Deadline,
         priority: Priority,
     ) -> AsyncIterator[Response]:
-        responses: List[ClosableResponse] = []
+        responses: list[ClosableResponse] = []
         try:
             for attempt in range(self._attempts_count):
                 send_result = await send_request(endpoint, request, deadline, priority)
@@ -159,14 +185,14 @@ class ParallelRequestStrategy(RequestStrategy):
         deadline: Deadline,
         priority: Priority,
     ) -> AsyncIterator[Response]:
-        completed_tasks: Set[asyncio.Future[SendRequestResult]] = set()
-        pending_tasks: Set[asyncio.Future[SendRequestResult]] = set()
+        completed_tasks: set[asyncio.Future[SendRequestResult]] = set()
+        pending_tasks: set[asyncio.Future[SendRequestResult]] = set()
         for attempt in range(0, self._attempts_count):
             schedule_request = self._schedule_request(attempt, send_request, endpoint, request, deadline, priority)
             pending_tasks.add(asyncio.create_task(schedule_request))
 
-        accepted_responses: List[ClosableResponse] = []
-        not_accepted_responses: List[ClosableResponse] = []
+        accepted_responses: list[ClosableResponse] = []
+        not_accepted_responses: list[ClosableResponse] = []
         try:
             try:
                 while pending_tasks:
